"use strict";

/* exported logger,assert */

require("../mocha-config.js");

var CustomMap = require('../../../main/js/map/CustomMap');
var OverviewDialog = require('../../../main/js/gui/OverviewDialog');
var Project = require('../../../main/js/map/data/Project');

var chai = require('chai');
var assert = chai.assert;
var logger = require('../logger');

describe('OverviewDialog', function() {

  it('open image', function() {
    return ServerConnector.readFile("testFiles/projectWithImages.json").then(function(fileContent) {
      var project = new Project(JSON.parse(fileContent));
      var options = helper.createOptions(project);
      var map = new CustomMap(options);

      var dialog = new OverviewDialog({
        element : testDiv,
        customMap : map
      });

      dialog.showOverview(project.getOverviewImages()[1].idObject);
      dialog.destroy();
    });
  });

  it('open invalid image', function() {
    return ServerConnector.readFile("testFiles/projectWithImages.json").then(function(fileContent) {
      var project = new Project(JSON.parse(fileContent));
      var options = helper.createOptions(project);
      var map = new CustomMap(options);

      var dialog = new OverviewDialog({
        element : testDiv,
        customMap : map
      });

      dialog.showOverview(-1123);
      dialog.destroy();
    });
  });

  describe('openLink', function() {
    it('link to map', function() {
      return ServerConnector.readFile("testFiles/projectWithImages.json").then(function(fileContent) {
        var project = new Project(JSON.parse(fileContent));
        var options = helper.createOptions(project);
        var map = new CustomMap(options);

        var dialog = new OverviewDialog({
          element : testDiv,
          customMap : map
        });
        
        dialog.openLink({
          type : "OverviewModelLink",
          modelLinkId : map.getId(),
          latLng : new google.maps.LatLng(1, 34)
        });
        assert.equal(logger.getWarnings().length, 0);
        assert.equal(1, map.getGoogleMap().getCenter().lat());
        assert.equal(34, map.getGoogleMap().getCenter().lng());
        dialog.destroy();
      });
    });
  });

});
