"use strict";

var Project = require('../../../../main/js/map/data/Project');

var logger = require('../../logger');

var chai = require('chai');
var assert = chai.assert;

describe('Project', function() {
  it("contructor", function() {
    return ServerConnector.readFile("testFiles/project.json").then(function(res) {
      var project = new Project(res);
      assert.ok(project);

      assert.equal(project.getVersion(), "0");
      assert.equal(project.getId(), 14898);
      assert.equal(project.getName(), "UNKNOWN DISEASE MAP");
      assert.equal(project.getProjectId(), "sample");
      assert.equal(project.getDescription(), "");
      assert.deepEqual(project.getOverviewImages(), []);

      var model = project.getModel();
      assert.equal(model.getName(), "UNKNOWN DISEASE MAP2");
      assert.equal(model.getId(), 15781);
      assert.equal(model.getTileSize(), 256);
      assert.equal(model.getWidth(), 1305);
      assert.equal(model.getHeight(), 473);
      assert.equal(model.getMinZoom(), 2);
      assert.equal(model.getMaxZoom(), 5);
      assert.equal(model.getLayoutsData().length, 3);

      assert.equal(model.getCenterLatLng().lat(), 79.18277721779353);
      assert.equal(model.getCenterLatLng().lng(), -135.06093781915757);
      assert.equal(model.getTopLeftLatLng().lat(), 85.05112877980659);
      assert.equal(model.getTopLeftLatLng().lng(), -180.0);
      assert.equal(model.getBottomRightLatLng().lat(), 81.26928406550978);
      assert.equal(model.getBottomRightLatLng().lng(), -90.0);

      assert.equal(logger.getWarnings().length, 0);
    });
  });
  it("contructor from Project obj", function() {
    return ServerConnector.readFile("testFiles/project.json").then(function(res) {
      var tmpProject = new Project(res);

      var project = new Project(tmpProject);
      assert.ok(project);

      assert.equal(project.getVersion(), "0");
      assert.equal(project.getId(), 14898);
      assert.equal(project.getName(), "UNKNOWN DISEASE MAP");
      assert.equal(project.getProjectId(), "sample");
      assert.equal(project.getDescription(), "");
      assert.deepEqual(project.getOverviewImages(), []);

      var model = project.getModel();
      assert.equal(model.getName(), "UNKNOWN DISEASE MAP2");
      assert.equal(model.getId(), 15781);
      assert.equal(model.getTileSize(), 256);
      assert.equal(model.getWidth(), 1305);
      assert.equal(model.getHeight(), 473);
      assert.equal(model.getMinZoom(), 2);
      assert.equal(model.getMaxZoom(), 5);
      assert.equal(model.getLayoutsData().length, 3);

      assert.equal(model.getCenterLatLng().lat(), 79.18277721779353);
      assert.equal(model.getCenterLatLng().lng(), -135.06093781915757);
      assert.equal(model.getTopLeftLatLng().lat(), 85.05112877980659);
      assert.equal(model.getTopLeftLatLng().lng(), -180.0);
      assert.equal(model.getBottomRightLatLng().lat(), 81.26928406550978);
      assert.equal(model.getBottomRightLatLng().lng(), -90.0);

      assert.equal(logger.getWarnings().length, 0);
    });
  });
});
